@@ -1,7 +1,15 @@
 #!/usr/bin/env python
 # coding:utf-8
-#code by:YasserBDJ96
-#email:yasser.bdj96@gmail.com
+#   |                                                          |
+# --+----------------------------------------------------------+--
+#   |   Code by : yasserbdj96                                  |
+#   |   Email   : yasser.bdj96@gmail.com                       |
+#   |   Github  : https://github.com/yasserbdj96               |
+#   |   BTC     : bc1q2dks8w8uurca5xmfwv4jwl7upehyjjakr3xga9   |
+# --+----------------------------------------------------------+--  
+#   |        all posts #yasserbdj96 ,all views my own.         |
+# --+----------------------------------------------------------+--
+#   |                                                          |
 
 #START{
 import os
@@ -12,16 +20,16 @@ class hexor:
     def __init__(self,return_opt=False,color_type="hex"):
         self.return_opt=return_opt
         self.color_type=color_type
-        
+
     #torgb:
-    def torgb(hex):
-        hex=hex.lstrip('#')
-        lv=len(hex)
-        return tuple(int(hex[i:i+lv//3],16) for i in range(0,lv,lv//3))
+    def torgb(hexc):
+        hexx=hexc.lstrip('#')
+        lv=len(hexx)
+        return tuple(int(hexx[i:i+lv//3],16) for i in range(0,lv,lv//3))
 
     #c:
     def c(self,text,foreground,background=False):
-        os.system('')
+        #os.system('')
         if self.color_type=="hex":
             f=hexor.torgb(foreground)
         elif self.color_type=="rgb":
@@ -35,11 +43,11 @@ class hexor:
                 b=background.split(",")
             if self.return_opt==True:
                 return f"\033[38;2;{f[0]};{f[1]};{f[2]}m\033[48;2;{b[0]};{b[1]};{b[2]}m{text}\033[0m"
-            elif self.return_opt==False:
+            if self.return_opt==False:
                 print(f"\033[38;2;{f[0]};{f[1]};{f[2]}m\033[48;2;{b[0]};{b[1]};{b[2]}m{text}\033[0m")
         else:
             if self.return_opt==True:
                 return f"\033[38;2;{f[0]};{f[1]};{f[2]}m{text}\033[0m"
-            elif self.return_opt==False:
+            if self.return_opt==False:
                 print(f"\033[38;2;{f[0]};{f[1]};{f[2]}m{text}\033[0m")
 #}END.
\ No newline at end of file
